@@ -56,6 +56,7 @@ void * tau_get_userevent(char *name);
 void tau_userevent(void *ue, double data);
 void tau_report_statistics(void);
 void tau_report_thread_statistics(void);
+void tau_dump(void);
 
 /*****************************************************************************
 * The following routines are called by the Fortran program and they in turn
@@ -133,9 +134,18 @@ void tau_profile_exit_(char *msg)
   return;
 }
 
+void tau_db_dump_(void)
+{
+  tau_dump();
+  return;
+}
+
 void tau_profile_init_(int *argc, char ***argv)
 {
   /* tau_init(*argc, *argv); */
+#ifndef TAU_MPI
+  tau_set_node(0); 
+#endif /* TAU_MPI */
   return;
 }
 
@@ -180,13 +190,10 @@ void tau_register_thread_(void)
   return;
 }
 
-#ifdef CRAYKAI
-/* Cray F90 specific extensions */
 void TAU_REGISTER_THREAD(void)
 {
   tau_register_thread();
 }
-#endif /* CRAYKAI */
 #endif /* PTHREADS || TULIPTHREADS */
 
 void tau_trace_sendmsg_(int *type, int *destination, int *length)
@@ -239,6 +246,7 @@ void tau_report_thread_statistics_(void)
 /* Cray F90 specific extensions */
 #ifdef CRAYKAI
 void _main();
+#endif /* CRAYKAI */
 void TAU_PROFILE_TIMER(void **ptr, char *fname, int *flen)
 {
 //#ifdef DEBUG_PROF
@@ -284,10 +292,21 @@ void TAU_PROFILE_EXIT(char *msg)
   tau_profile_exit_(msg);
 }
 
+void TAU_DB_DUMP(void)
+{
+  tau_dump();
+  return;
+}
+
 void TAU_PROFILE_INIT()
 {
+#ifdef CRAYKAI
   _main();
+#endif /* CRAYKAI */
   // tau_profile_init_(argc, argv);
+#ifndef TAU_MPI
+  tau_set_node(0); 
+#endif /* TAU_MPI */
 }
 
 void TAU_PROFILE_SET_NODE(int *node)
@@ -356,7 +375,6 @@ void TAU_REPORT_THREAD_STATISTICS(void)
 {
   tau_report_thread_statistics();
 }
-#endif /* CRAYKAI */
 
 #if (defined (TAU_XLC) || defined(TAU_AIX))
 void tau_profile_timer(int **profiler, char *fname)
@@ -391,6 +409,9 @@ void tau_profile_stop(int **profiler)
 
 void tau_profile_init()
 {
+#ifndef TAU_MPI
+  tau_set_node(0); 
+#endif /* TAU_MPI */
   
 }
 
@@ -404,6 +425,11 @@ void tau_profile_exit(char *msg)
   tau_exit(msg);
 }
 
+void tau_db_dump(void)
+{
+  tau_dump();
+}
+
 void tau_profile_set_context(int *context)
 {
   tau_set_context(*context);
@@ -494,10 +520,19 @@ void tau_profile_exit__(char *msg)
   tau_profile_exit_(msg);
 }
 
+void tau_db_dump__(void)
+{
+  tau_dump();
+  return;
+}
+
 void tau_profile_init__()
 {
   //_main();
   // tau_profile_init_(argc, argv);
+#ifndef TAU_MPI
+  tau_set_node(0); 
+#endif /* TAU_MPI */
 }
 
 void tau_profile_set_node__(int *node)
@@ -562,6 +597,6 @@ void tau_report_thread_statistics__(void)
 
 /***************************************************************************
  * $RCSfile: TauFAPI.cpp,v $   $Author: sameer $
- * $Revision: 1.16 $   $Date: 2001/02/14 21:58:40 $
- * POOMA_VERSION_ID: $Id: TauFAPI.cpp,v 1.16 2001/02/14 21:58:40 sameer Exp $ 
+ * $Revision: 1.19 $   $Date: 2001/11/09 20:08:29 $
+ * POOMA_VERSION_ID: $Id: TauFAPI.cpp,v 1.19 2001/11/09 20:08:29 sameer Exp $ 
  ***************************************************************************/
